@@ -20,11 +20,6 @@ def showy(layout, dataframe, show=True, preprocess_fnc=preprocess_layout):
     """It displays the desired graphs described by the provided layout
     thanks to the provided key-value object which contains
     the required data
-
-    Input:
-    ------
-    data : key-value object
-    layout : nested object
     """
     validate_layout(layout)
 
@@ -32,6 +27,8 @@ def showy(layout, dataframe, show=True, preprocess_fnc=preprocess_layout):
     if type(dataframes) not in [tuple, list]:
         dataframes = [dataframes]
 
+    comparison_mode = len(dataframes)>1
+
     available_varnames = _get_available_varnames(dataframes)
 
     layout = preprocess_fnc(layout, available_varnames)
@@ -46,7 +43,7 @@ def showy(layout, dataframe, show=True, preprocess_fnc=preprocess_layout):
         if (graph_position > max_graphs or figure_number == 0):
             graph_position = 1
             figure_number += 1
-            figure = _build_new_figure(fig_number=figure_number, **display_params)
+            figure = _build_new_figure(fig_number=figure_number,comparison_mode=comparison_mode, **display_params)
 
         subplot = figure.add_subplot(*fig_layout, graph_position)
         _build_new_graph(subplot, graph_layout, dataframes)
@@ -91,11 +88,13 @@ def _initialize_display(layout):
 
 
 def _build_new_figure(dpi=None, inches_size=(14, 8), fig_number=None,
-                      n_figs=None, title="", **kwargs):
+                      n_figs=None, title="",comparison_mode=False, **kwargs):
     figure = plt.figure(dpi=dpi)
     figure.set_size_inches(*inches_size)
 
     figure_name = title
+    if comparison_mode:
+        figure_name+= " (comparison)"
     if fig_number is not None and n_figs is not None and n_figs > 1:
         figure_name += f' ({fig_number}/{n_figs})'
 
@@ -119,33 +118,28 @@ def _build_new_graph(ax, graph_layout, dataframes):
     ax.set_title(graph_layout.get('title', None), fontweight='bold')
 
     for data_number, dataframe in enumerate(dataframes):
+        linewidth=2
+        if data_number > 0:
+            linewidth=4
         x = dataframe[graph_layout["x_var"]]
         for curve_number, curve_layout in enumerate(graph_layout["curves"]):
             symbols_markevery = _symbols_markevery(x)
             custom_style = _custom_cycler_iterate(curve_number, data_number, symbols_markevery)
             try :
-                ax.plot(x, dataframe[curve_layout["var"]], **custom_style)
+                ax.plot(x, dataframe[curve_layout["var"]], **custom_style, linewidth=linewidth)
             except KeyError:
                 print(f"Could not find the key {curve_layout['var']} in current dataframe")
             
 
     # improve legends
     handles = []
+        
     for curve_number, curve_layout in enumerate(graph_layout['curves']):
         label = curve_layout.get('legend', None)
         custom_style = _custom_cycler_iterate(curve_number, 0)
-
         if label is not None:
             handles.append(Line2D([0], [0], label=label, **custom_style))
 
-    n_data = len(dataframes)
-    if n_data > 1:
-        for i in range(n_data):
-            label = f'data {i}'
-            custom_style = _custom_cycler_iterate(0, i)
-            custom_style['color'] = 'black'
-            handles.append(Line2D([0], [0], label=label, **custom_style))
-
     if handles:
         ax.legend(handles=handles, loc=0)
 
@@ -159,9 +153,8 @@ def _custom_cycler_iterate(index, family_index=0, markevery=None):
     other data.
     """
 
-    custom_cycler = ['#4477AA', '#66CCEE', '#228833', '#CCBB44', '#EE6677',
-                     '#AA3377', '#BBBBBB']
-    custom_linestyles = ['solid', 'dashed', 'dotted', 'dash']
+    custom_cycler =     ['#4477AA','#66CCEE','#228833', '#CCBB44', '#EE6677', '#AA3377', '#BBBBBB']
+    custom_linestyles = ['solid',  'dashed' , 'dotted', 'dash', 'dash', 'dash', 'dash']
     custom_symbols = ["d", "o", "v", "^", ">", "<", "s"]
 
     index_ = index % len(custom_cycler)
